@@ -1,9 +1,10 @@
 from .base import *
 from .cast import *
+from .context import *
 from .date import *
-from .excel import *
+from .gcloud import *
 from .logs import *
 from .map import *
 from .parse import *
 
-__version__ = "1.1.4"
\ No newline at end of file
+__version__ = "2.0.7"
\ No newline at end of file
